@@ -19,6 +19,29 @@ refer to dice in a pool.
 
 __docformat__ = 'google'
 
+from icepool.constant import SpecialValue
+
+Reroll = SpecialValue.Reroll
+"""Indicates that an outcome should be rerolled (with unlimited depth).
+
+This can be used in place of outcomes in many places. See individual function
+and method descriptions for details.
+
+This effectively removes the outcome from the probability space, along with its
+contribution to the denominator.
+
+This can be used for conditional probability by removing all outcomes not
+consistent with the given observations.
+
+Operation in specific cases:
+
+* When used with `Again`, only that stage is rerolled, not the entire `Again`
+    tree.
+* To reroll with limited depth, use `Die.reroll()`, or `Again()` with no
+    modification.
+* When used with `OutcomeCountEvaluator`, the entire evaluation is rerolled.
+"""
+
 # Expose certain names at top-level.
 
 from icepool.die.func import (standard, d, __getattr__, bernoulli, coin,
@@ -27,7 +50,7 @@ from icepool.die.func import (standard, d, __getattr__, bernoulli, coin,
                               accumulate, apply, apply_sorted)
 
 from icepool.population import Population
-from icepool.die.die import Die
+from icepool.die.die import implicit_convert_to_die, Die
 from icepool.again import Again
 from icepool.die.die_with_truth import DieWithTruth
 
@@ -48,23 +71,12 @@ from icepool.evaluators import (
 from icepool.deck import Deck
 from icepool.deal import Deal
 
-import enum
-
-
-class SpecialValue(enum.Enum):
-    Reroll = 'Reroll'
-    """Indicates an outcome should be rerolled (with no max depth)."""
-
-
-Reroll = SpecialValue.Reroll
-"""Indicates an outcome should be rerolled (with no max depth)."""
-
 __all__ = [
     'standard', 'd', 'bernoulli', 'coin', 'Die', 'Population', 'Again',
     'CountsKeysView', 'CountsValuesView', 'CountsItemsView',
     'from_cumulative_quantities', 'from_rv', 'align', 'align_range', 'lowest',
     'highest', 'min_outcome', 'max_outcome', 'reduce', 'accumulate', 'apply',
-    'apply_sorted', 'Reroll', 'OutcomeCountGenerator', 'Pool', 'standard_pool',
-    'OutcomeCountEvaluator', 'Order', 'JointEvaluator', 'SumEvaluator', 'Deck',
-    'Deal', 'clear_pool_cache'
+    'apply_sorted', 'Reroll', 'Unlimited', 'OutcomeCountGenerator', 'Pool',
+    'standard_pool', 'OutcomeCountEvaluator', 'Order', 'JointEvaluator',
+    'SumEvaluator', 'Deck', 'Deal', 'clear_pool_cache'
 ]
