@@ -89,7 +89,7 @@ class Pool(OutcomeCountGenerator):
             )
 
         dice, times = icepool.creation_args.itemize(dice, times)
-        dice = tuple(icepool.Die([die]) for die in dice)
+        dice = tuple(icepool.implicit_convert_to_die(die) for die in dice)
 
         dice_counts: MutableMapping['icepool.Die', int] = defaultdict(int)
         for die, qty in zip(dice, times):
@@ -516,7 +516,7 @@ def standard_pool(die_sizes: Collection[int] | Mapping[int, int]) -> 'Pool':
             Or, a mapping of die sizes to how many dice of that size to put
             into the pool.
     """
-    if icepool.creation_args.is_mapping(die_sizes):
+    if isinstance(die_sizes, Mapping):
         die_sizes = list(
             itertools.chain.from_iterable(
                 [k] * v for k, v in die_sizes.items()))  # type: ignore
